==> pulumi-azure-native-kotlin-2.30.0.0-sources.jar: com/pulumi/azurenative/cdn/kotlin/outputs/CdnManagedHttpsParametersResponse.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.cdn.kotlin.outputs

import kotlin.String
import kotlin.Suppress

/**
 * Defines the certificate source parameters using CDN managed certificate for enabling SSL.
 * @property certificateSource Defines the source of the SSL certificate.
 * Expected value is 'Cdn'.
 * @property certificateSourceParameters Defines the certificate source parameters using CDN managed certificate for enabling SSL.
 * @property minimumTlsVersion TLS protocol version that will be used for Https
 * @property protocolType Defines the TLS extension protocol that is used for secure delivery.
 */
public data class CdnManagedHttpsParametersResponse(
    public val certificateSource: String,
    public val certificateSourceParameters: CdnCertificateSourceParametersResponse,
    public val minimumTlsVersion: String? = null,
    public val protocolType: String,
) {
    public companion object {
        public
        fun toKotlin(javaType: com.pulumi.azurenative.cdn.outputs.CdnManagedHttpsParametersResponse):
            CdnManagedHttpsParametersResponse = CdnManagedHttpsParametersResponse(
            certificateSource = javaType.certificateSource(),
            certificateSourceParameters = javaType.certificateSourceParameters().let({ args0 ->
                com.pulumi.azurenative.cdn.kotlin.outputs.CdnCertificateSourceParametersResponse.Companion.toKotlin(args0)
            }),
            minimumTlsVersion = javaType.minimumTlsVersion().map({ args0 -> args0 }).orElse(null),
            protocolType = javaType.protocolType(),
        )
    }
}

==> pulumi-azure-native-kotlin-2.44.1.0-sources.jar: com/pulumi/azurenative/cdn/kotlin/outputs/CdnManagedHttpsParametersResponse.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.cdn.kotlin.outputs

import kotlin.String
import kotlin.Suppress

/**
 * Defines the certificate source parameters using CDN managed certificate for enabling SSL.
 * @property certificateSource Defines the source of the SSL certificate.
 * Expected value is 'Cdn'.
 * @property certificateSourceParameters Defines the certificate source parameters using CDN managed certificate for enabling SSL.
 * @property minimumTlsVersion TLS protocol version that will be used for Https
 * @property protocolType Defines the TLS extension protocol that is used for secure delivery.
 */
public data class CdnManagedHttpsParametersResponse(
    public val certificateSource: String,
    public val certificateSourceParameters: CdnCertificateSourceParametersResponse,
    public val minimumTlsVersion: String? = null,
    public val protocolType: String,
) {
    public companion object {
        public fun toKotlin(javaType: com.pulumi.azurenative.cdn.outputs.CdnManagedHttpsParametersResponse): CdnManagedHttpsParametersResponse = CdnManagedHttpsParametersResponse(
            certificateSource = javaType.certificateSource(),
            certificateSourceParameters = javaType.certificateSourceParameters().let({ args0 ->
                com.pulumi.azurenative.cdn.kotlin.outputs.CdnCertificateSourceParametersResponse.Companion.toKotlin(args0)
            }),
            minimumTlsVersion = javaType.minimumTlsVersion().map({ args0 -> args0 }).orElse(null),
            protocolType = javaType.protocolType(),
        )
    }
}
